(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[     15883,        532]
NotebookOptionsPosition[     10943,        383]
NotebookOutlinePosition[     12799,        434]
CellTagsIndexPosition[     12721,        429]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Parallel Computing Terminology", "Section",
 CellChangeTimes->{{3.4956628947113733`*^9, 3.4956629024069815`*^9}}],

Cell["\<\
Here, we describe common parallel computing terminology:\
\>", "Text",
 CellChangeTimes->{{3.49566290419123*^9, 3.4956629168137846`*^9}}],

Cell[CellGroupData[{

Cell["What is parallelism?", "Item2",
 CellChangeTimes->{{3.495664337901555*^9, 3.4956643544392996`*^9}, 
   3.4957986611627884`*^9}],

Cell["Data parallelism", "Item2",
 CellChangeTimes->{{3.495664355244995*^9, 3.4956643612149506`*^9}, 
   3.4957986629699697`*^9}],

Cell["Task parallelism", "Item2",
 CellChangeTimes->{{3.49566436244449*^9, 3.4956643648068857`*^9}, 
   3.495798663655957*^9}],

Cell["Classification of operations", "Item2",
 CellChangeTimes->{{3.4956643689007926`*^9, 3.4956643816200314`*^9}}],

Cell["Possible issues with data parallelism", "Item2",
 CellChangeTimes->{{3.495664389268762*^9, 3.495664393884174*^9}, 
   3.495798664185817*^9}]
}, Open  ]]
}, Open  ]],

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Parallelize", "Section",
 CellChangeTimes->{{3.4956629209662876`*^9, 3.495662922814015*^9}}],

Cell["\<\
To make a computation run in parallel.\
\>", "Text",
 CellChangeTimes->{{3.495662924686157*^9, 3.4956629777731566`*^9}}],

Cell["\<\
It involves splitting either the data or the problem into small chunks and \
solving each in parallel.\
\>", "Text",
 CellChangeTimes->{3.495662980540841*^9, 3.495663588027058*^9, 
  3.4957986666136074`*^9}],

Cell["\<\
Each unit of execution is called a thread.\
\>", "Text",
 CellChangeTimes->{
  3.495662980540841*^9, {3.495663580067768*^9, 3.4956635861471033`*^9}}]
}, Open  ]],

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Data Parallelism", "Section",
 CellChangeTimes->{{3.4956629847167826`*^9, 3.495662988068474*^9}, 
   3.4957986677328496`*^9}],

Cell["\<\
Split the data into small chunks and perform same operation on each processor:\
\>", "Text",
 CellChangeTimes->{{3.495662991380124*^9, 3.4956629979643617`*^9}, {
  3.495663028099308*^9, 3.4956630591063576`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"LaunchKernels", "[", "]"}]], "Input",
 CellChangeTimes->{{3.4956630613164034`*^9, 3.495663072482848*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"KernelObject", "[", 
    RowBox[{"1", ",", "\<\"local\"\>"}], "]"}], ",", 
   RowBox[{"KernelObject", "[", 
    RowBox[{"2", ",", "\<\"local\"\>"}], "]"}], ",", 
   RowBox[{"KernelObject", "[", 
    RowBox[{"3", ",", "\<\"local\"\>"}], "]"}], ",", 
   RowBox[{"KernelObject", "[", 
    RowBox[{"4", ",", "\<\"local\"\>"}], "]"}]}], "}"}]], "Output",
 CellChangeTimes->{3.495663074912629*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ParallelMap", "[", 
  RowBox[{"Sin", ",", 
   RowBox[{"RandomReal", "[", 
    RowBox[{"1", ",", "10"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.4956630613164034`*^9, 3.49566309340162*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.1716124164692689`", ",", "0.5580716695264918`", ",", 
   "0.3020557918721621`", ",", "0.655326504220803`", ",", 
   "0.12136744155273536`", ",", "0.8160676983084729`", ",", 
   "0.8130134563677622`", ",", "0.06417613417716238`", ",", 
   "0.3554184391701923`", ",", "0.4326037765034272`"}], "}"}]], "Output",
 CellChangeTimes->{3.4956630938401136`*^9}]
}, Open  ]]
}, Open  ]],

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Task Parallelism", "Section",
 CellChangeTimes->{{3.4956631095067306`*^9, 3.495663111880845*^9}, 
   3.4957986688013506`*^9}],

Cell["\<\
Split operations into small chunks and perform different operations on each \
processor:\
\>", "Text",
 CellChangeTimes->{{3.495663114193434*^9, 3.4956631294166746`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"ParallelEvaluate", "[", 
   RowBox[{"task", ":=", 
    RowBox[{"{", 
     RowBox[{"$KernelID", ",", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"EvenQ", "[", "$KernelID", "]"}], ",", "Sin", ",", "Cos"}], 
       "]"}]}], "}"}]}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.495663206350293*^9, 3.4956632321276503`*^9}, {
  3.4956632838464327`*^9, 3.495663319204236*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ParallelMap", "[", 
  RowBox[{"task", ",", 
   RowBox[{"Range", "[", "10", "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.4956631563552094`*^9, 3.4956631999916506`*^9}, {
  3.49566329814874*^9, 3.4956633101960773`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"{", 
     RowBox[{"4", ",", "Sin"}], "}"}], "[", "1", "]"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"4", ",", "Sin"}], "}"}], "[", "2", "]"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"3", ",", "Cos"}], "}"}], "[", "3", "]"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"3", ",", "Cos"}], "}"}], "[", "4", "]"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"2", ",", "Sin"}], "}"}], "[", "5", "]"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1", ",", "Cos"}], "}"}], "[", "6", "]"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"4", ",", "Sin"}], "}"}], "[", "7", "]"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"3", ",", "Cos"}], "}"}], "[", "8", "]"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"2", ",", "Sin"}], "}"}], "[", "9", "]"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1", ",", "Cos"}], "}"}], "[", "10", "]"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.4956631797965393`*^9, 3.4956631837898564`*^9}, {
  3.4956632233861036`*^9, 3.495663250409602*^9}, {3.4956632851667957`*^9, 
  3.495663320174*^9}}]
}, Open  ]]
}, Open  ]],

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["MIMD", "Section",
 CellChangeTimes->{{3.4956634287045345`*^9, 3.4956634293276052`*^9}}],

Cell["\<\
Multiple Instructions Multiple Data.\
\>", "Text",
 CellChangeTimes->{{3.4956634327125006`*^9, 3.495663447350758*^9}}],

Cell["Like sequential computation:", "Text",
 CellChangeTimes->{{3.495663453518964*^9, 3.4956634596549416`*^9}, {
  3.4957986077953105`*^9, 3.4957986109276285`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Sin", "[", "2", "]"}], ";", 
  RowBox[{"Cos", "[", "2", "]"}], ";", 
  RowBox[{"Tan", "[", "2", "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.4956634612634015`*^9, 3.495663481423355*^9}}]
}, Open  ]],

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["SIMD", "Section",
 CellChangeTimes->{{3.4956634864303837`*^9, 3.495663486766334*^9}}],

Cell["\<\
Single Instruction Multiple Data.\
\>", "Text",
 CellChangeTimes->{{3.4956634882859235`*^9, 3.495663495213924*^9}}],

Cell["Vectorized computing:", "Text",
 CellChangeTimes->{{3.4956634965479593`*^9, 3.495663502253257*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Map", "[", 
  RowBox[{"Sin", ",", 
   RowBox[{"Range", "[", "10", "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.4956635083823986`*^9, 3.49566351407207*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"Sin", "[", "1", "]"}], ",", 
   RowBox[{"Sin", "[", "2", "]"}], ",", 
   RowBox[{"Sin", "[", "3", "]"}], ",", 
   RowBox[{"Sin", "[", "4", "]"}], ",", 
   RowBox[{"Sin", "[", "5", "]"}], ",", 
   RowBox[{"Sin", "[", "6", "]"}], ",", 
   RowBox[{"Sin", "[", "7", "]"}], ",", 
   RowBox[{"Sin", "[", "8", "]"}], ",", 
   RowBox[{"Sin", "[", "9", "]"}], ",", 
   RowBox[{"Sin", "[", "10", "]"}]}], "}"}]], "Output",
 CellChangeTimes->{3.495663514332822*^9}]
}, Open  ]]
}, Open  ]],

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["\<\
Problems with Parallel Programming\
\>", "Section",
 CellChangeTimes->{{3.4956635286048546`*^9, 3.4956635353404646`*^9}}],

Cell["\<\
Dead locks, race conditions, ...\
\>", "Text",
 CellChangeTimes->{{3.4956635378522797`*^9, 3.495663543835908*^9}, {
  3.4957986203763*^9, 3.4957986207353945`*^9}}],

Cell["Bandwidth limitations.", "Text",
 CellChangeTimes->{{3.4957986218273144`*^9, 3.495798626849757*^9}}]
}, Open  ]],

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Dead Locks", "Section",
 CellChangeTimes->{{3.4956635582690797`*^9, 3.495663560339472*^9}}],

Cell["\<\
When two threads end in a state where each is locking each other\
\[CloseCurlyQuote]s resources.\
\>", "Text",
 CellChangeTimes->{{3.495663561844412*^9, 3.495663595611334*^9}, {
  3.495663763246677*^9, 3.4956637784142513`*^9}}]
}, Open  ]],

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Race Conditions", "Section",
 CellChangeTimes->{{3.4956637424558396`*^9, 3.49566374445494*^9}}],

Cell["\<\
When two threads overwrite each others results\
\>", "Text",
 CellChangeTimes->{{3.495663745750888*^9, 3.495663758334379*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"SetSharedVariable", "[", "xs", "]"}], ";"}]], "Input",
 CellChangeTimes->{3.4956636335971675`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"xs", "=", "0"}], ";"}]], "Input",
 CellChangeTimes->{{3.4956636335971675`*^9, 3.495663644074132*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"ParallelDo", "[", 
   RowBox[{
    RowBox[{"xs", "=", "$KernelID"}], ",", 
    RowBox[{"{", "100", "}"}]}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.4956636335971675`*^9, 3.495663696235315*^9}}],

Cell[CellGroupData[{

Cell[BoxData["xs"], "Input",
 CellChangeTimes->{{3.495663675369279*^9, 3.4956636754571733`*^9}}],

Cell[BoxData["1"], "Output",
 CellChangeTimes->{{3.4956636758253517`*^9, 3.495663700615366*^9}}]
}, Open  ]]
}, Open  ]],

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Bandwidth", "Section",
 CellChangeTimes->{{3.4956643982280903`*^9, 3.49566440116375*^9}}],

Cell["\<\
How to share data between threads or computers.\
\>", "Text",
 CellChangeTimes->{{3.4956644057557235`*^9, 3.4956644581542196`*^9}}],

Cell["\<\
Memory, network, or disk bandwidth is slow compared to CPU/GPU speed.\
\>", "Text"]
}, Open  ]],

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell["Next: CUDA Architecture", "Section",
 CellChangeTimes->{{3.495663801933709*^9, 3.4956638125649767`*^9}, {
  3.495798654652251*^9, 3.4957986550181756`*^9}}]
},
ScreenStyleEnvironment->"SlideShow",
WindowSize->{975, 760},
WindowMargins->{{Automatic, -1454}, {114, Automatic}},
TaggingRules->{
 "DocuToolsSettings" -> {
   "$ApplicationName" -> "CUDALink", "$LinkBase" -> "CUDALink", 
    "$DocumentationDirectory" -> 
    "C:\\Users\\abduld\\WolframWorkspaces\\Base2\\CUDALink\\CUDALink\\\
Documentation\\English\\", "$ApplicationDirectory" -> 
    "C:\\Users\\abduld\\WolframWorkspaces\\Base2\\CUDALink\\CUDALink"}, 
  "SlideshowSettings" -> {"Toolbar" -> True}},
FrontEndVersion->"8.0 for Microsoft Windows (64-bit) (October 10, 2010)",
StyleDefinitions->FrontEnd`FileName[{"Book"}, "Textbook.nb", 
  CharacterEncoding -> "WindowsANSI"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "SlideShowHeader"->{
  Cell[557, 20, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[1628, 56, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[2345, 83, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[4073, 139, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[6343, 215, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[7064, 240, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[8223, 281, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[8743, 301, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[9184, 317, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[10272, 358, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[10711, 376, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"SlideShowHeader", 11742, 403}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[557, 20, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[646, 25, 119, 1, 80, "Section"],
Cell[768, 28, 147, 3, 47, "Text"],
Cell[CellGroupData[{
Cell[940, 35, 133, 2, 18, "Item2"],
Cell[1076, 39, 129, 2, 18, "Item2"],
Cell[1208, 43, 126, 2, 18, "Item2"],
Cell[1337, 47, 115, 1, 18, "Item2"],
Cell[1455, 50, 146, 2, 18, "Item2"]
}, Open  ]]
}, Open  ]],
Cell[1628, 56, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[1717, 61, 98, 1, 80, "Section"],
Cell[1818, 64, 130, 3, 47, "Text"],
Cell[1951, 69, 217, 5, 79, "Text"],
Cell[2171, 76, 159, 4, 47, "Text"]
}, Open  ]],
Cell[2345, 83, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[2434, 88, 131, 2, 80, "Section"],
Cell[2568, 92, 221, 4, 47, "Text"],
Cell[CellGroupData[{
Cell[2814, 100, 129, 2, 50, "Input"],
Cell[2946, 104, 443, 11, 85, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3426, 120, 220, 5, 50, "Input"],
Cell[3649, 127, 397, 8, 85, "Output"]
}, Open  ]]
}, Open  ]],
Cell[4073, 139, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[4162, 144, 131, 2, 80, "Section"],
Cell[4296, 148, 180, 4, 47, "Text"],
Cell[4479, 154, 422, 11, 85, "Input"],
Cell[CellGroupData[{
Cell[4926, 169, 244, 5, 50, "Input"],
Cell[5173, 176, 1143, 35, 119, "Output"]
}, Open  ]]
}, Open  ]],
Cell[6343, 215, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[6432, 220, 93, 1, 80, "Section"],
Cell[6528, 223, 128, 3, 47, "Text"],
Cell[6659, 228, 165, 2, 47, "Text"],
Cell[6827, 232, 222, 5, 50, "Input"]
}, Open  ]],
Cell[7064, 240, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[7153, 245, 91, 1, 80, "Section"],
Cell[7247, 248, 125, 3, 47, "Text"],
Cell[7375, 253, 105, 1, 47, "Text"],
Cell[CellGroupData[{
Cell[7505, 258, 182, 4, 50, "Input"],
Cell[7690, 264, 506, 13, 85, "Output"]
}, Open  ]]
}, Open  ]],
Cell[8223, 281, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[8312, 286, 131, 3, 80, "Section"],
Cell[8446, 291, 173, 4, 47, "Text"],
Cell[8622, 297, 106, 1, 47, "Text"]
}, Open  ]],
Cell[8743, 301, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[8832, 306, 97, 1, 80, "Section"],
Cell[8932, 309, 237, 5, 47, "Text"]
}, Open  ]],
Cell[9184, 317, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[9273, 322, 101, 1, 80, "Section"],
Cell[9377, 325, 136, 3, 47, "Text"],
Cell[9516, 330, 133, 3, 50, "Input"],
Cell[9652, 335, 136, 3, 50, "Input"],
Cell[9791, 340, 234, 6, 50, "Input"],
Cell[CellGroupData[{
Cell[10050, 350, 96, 1, 50, "Input"],
Cell[10149, 353, 96, 1, 50, "Output"]
}, Open  ]]
}, Open  ]],
Cell[10272, 358, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[10361, 363, 95, 1, 80, "Section"],
Cell[10459, 366, 141, 3, 47, "Text"],
Cell[10603, 371, 93, 2, 47, "Text"]
}, Open  ]],
Cell[10711, 376, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[10778, 379, 161, 2, 80, "Section"]
}
]
*)

(* End of internal cache information *)
